# ----------------------------------------------------------------
# ----------------------------------------------------------------
## Project: AHL Germany
## Author: Carolin Kilian
## Start Date: 18.03.2024
# ----------------------------------------------------------------
# ----------------------------------------------------------------

# --------------------------------------------------------------------------------------

# ----------------------------------------------------------------
# ----------------------------------------------------------------
# LIBARIES
# ----------------------------------------------------------------
# ----------------------------------------------------------------

library(tidyverse)
library(nnet)
library(janitor)
library(dplyr)
library(writexl)
library(ggplot2)

# --------------------------------------------------------------------------------------

# ----------------------------------------------------------------
# LOAD DATA
# ----------------------------------------------------------------

rm(list = ls())
setwd("/Users/carolinkilian/Desktop/AHL Survey Deutschland/")
DATE <- 20240528

data <- read.csv("20240521_AHL_data_clean.csv", na.strings = c(""))

# ----------------------------------------------------------------
# PREPARE DATA 
# ----------------------------------------------------------------

data <- data %>%
  mutate(gender = factor(gender, levels = c(1, 0), labels = c("men", "women")),
         agegroup = factor(agegroup, levels = c(1, 2, 3), labels = c("18-34", "35-49", "50+")),
         education = factor(education, levels = c(3, 2, 1), labels = c("high", "middle", "low")),
         auditc_3 = factor(auditc_3, levels = c(2, 1, 3), labels = c("low risk", "abstainer", "high risk")),
         ahlscore = factor(ahlscore, levels = c(0, 1)),
         ahlscore_lab = factor(ahlscore, levels = c(0, 1), labels = c("sufficient", "insufficent")),
         ahlscore_mis = factor(ahlscore_mis, levels = c(0, 1, 2), labels = c("sufficient", "inadequate", "missing")),
         hlsscore = factor(hlsscore, levels = c(3, 2, 1), labels = c("sufficient", "problematic", "inadequate")))

data_comp <- data %>% filter(!is.na(ahlscore))

# ----------------------------------------------------------------
# DESCRIPTIVES
# ----------------------------------------------------------------

#Mean age by sex
data_comp %>% group_by(gender) %>%
  summarise(age_mean = mean(age), 
            age_sd = sd(age))
         
#AHL by sex
data_comp %>% group_by(gender) %>%
  summarise(ahl_insu = mean(as.numeric(as.character(ahlscore))),
            ahl_suff = 1-mean(as.numeric(as.character(ahlscore))))

#Table 1 

out_prep <- data_comp %>% 
  mutate(#group = paste0(gender, "_", ahlscore_lab),
         age_1834 = ifelse(agegroup == "18-34", 1, 0), 
         age_3549 = ifelse(agegroup == "35-49", 1, 0), 
         age_50 = ifelse(agegroup == "50+", 1, 0), 
         edu_low = ifelse(education == "low", 1, 0), 
         edu_mid = ifelse(education == "middle", 1, 0), 
         edu_high = ifelse(education == "high", 1, 0), 
         alc_abs = ifelse(auditc_3 == "abstainer", 1, 0), 
         alc_low = ifelse(auditc_3 == "low risk", 1, 0), 
         alc_high = ifelse(auditc_3 == "high risk", 1, 0), 
         ahl_suff = ifelse(ahlscore_lab == "sufficient", 1, 0), 
         ahl_insu = ifelse(ahlscore_lab == "insufficent", 1, 0), 
         hls_inad = ifelse(hlsscore == "inadequate", 1, 0), 
         hls_prob = ifelse(hlsscore == "problematic", 1, 0), 
         hls_suff = ifelse(hlsscore == "sufficient", 1, 0)) 

output1 <- rbind(out_prep %>% group_by(gender, level=agegroup) %>%
  summarise(var = "agegroup",
            p_sufficient = mean(ahl_suff), n_sufficient = sum(ahl_suff), 
            p_insufficent = mean(ahl_insu), n_insufficent = sum(ahl_insu)),
  out_prep %>% group_by(gender, level=education) %>%
    summarise(var = "education",
              p_sufficient = mean(ahl_suff), n_sufficient = sum(ahl_suff), 
              p_insufficent = mean(ahl_insu), n_insufficent = sum(ahl_insu)),
  out_prep %>% group_by(gender, level=auditc_3) %>%
    summarise(var = "alcohol",
              p_sufficient = mean(ahl_suff), n_sufficient = sum(ahl_suff), 
              p_insufficent = mean(ahl_insu), n_insufficent = sum(ahl_insu)),
  out_prep %>% group_by(gender, level=hlsscore) %>%
    summarise(var = "hls",
              p_sufficient = mean(ahl_suff), n_sufficient = sum(ahl_suff), 
              p_insufficent = mean(ahl_insu), n_insufficent = sum(ahl_insu))) %>% ungroup()

output2 <- out_prep %>% group_by(gender) %>%
  summarise(p_age_1834 = mean(age_1834), n_age_1834 = sum(age_1834), 
            p_age_3549 = mean(age_3549), n_age_3549 = sum(age_3549),
            p_age_50 = mean(age_50), n_age_50 = sum(age_50),
            p_edu_low = mean(edu_low), n_edu_low = sum(edu_low),
            p_edu_mid = mean(edu_mid), n_edu_mid = sum(edu_mid),
            p_edu_high = mean(edu_high), n_edu_high = sum(edu_high),
            p_alc_abs = mean(alc_abs), n_alc_abs = sum(alc_abs),
            p_alc_low = mean(alc_low), n_alc_low = sum(alc_low),
            p_alc_high = mean(alc_high), n_alc_high = sum(alc_high),
            #p_ahl_suff = mean(ahl_suff), n_ahl_suff = sum(ahl_suff),
            #p_ahl_insu = mean(ahl_insu), n_ahl_insu = mean(ahl_insu),
            p_hls_inad = mean(hls_inad), n_hls_inad = sum(hls_inad),  
            p_hls_prob = mean(hls_prob), n_hls_prob = sum(hls_prob),
            p_hls_suff = mean(hls_suff), n_hls_suff = sum(hls_suff)) %>% t(.) %>% 
  as.data.frame() %>% rownames_to_column(., "var") %>% row_to_names(row_number = 1) 

#Chi-square tests for Table 1

out.w <- output1 %>% filter(gender == "women") %>%
  dplyr::select(c("var", "level", "n_insufficent", "n_sufficient"))
out.m <- output1 %>% filter(gender == "men") %>%
  dplyr::select(c("var", "level", "n_insufficent", "n_sufficient"))

out_list_women <- list()
for (var in unique(out.w$var)){
  sub <- out.w %>% filter(var == !!paste0(var)) %>% dplyr::select(-c(var, level)) %>%
    mutate_if(is.character, as.numeric)
  test <- chisq.test(sub)
  out_list_women[[paste(var)]]$var <- paste0(var)
  out_list_women[[paste(var)]]$X <- test$statistic
  out_list_women[[paste(var)]]$df <- test$parameter
  out_list_women[[paste(var)]]$pval <- test$p.value
}

out_list_men <- list()
for (var in unique(out.m$var)){
  sub <- out.m %>% filter(var == !!paste0(var)) %>% dplyr::select(-c(var, level)) %>%
    mutate_if(is.character, as.numeric)
  test <- chisq.test(sub)
  out_list_men[[paste(var)]]$var <- paste0(var)
  out_list_men[[paste(var)]]$X <- test$statistic
  out_list_men[[paste(var)]]$df <- test$parameter
  out_list_men[[paste(var)]]$pval <- test$p.value
}

out_chi <- rbind(cbind(gender = "women", do.call(rbind, out_list_women)), 
                 cbind(gender = "men", do.call(rbind, out_list_men))) %>% 
  as.data.frame() %>% mutate_at(1:5, as.character)

#Export
#write_xlsx(output1, paste0("Output/", DATE, "_desc_AHLxSEX.xlsx"))
#write_xlsx(output2, paste0("Output/", DATE, "_desc_AHLxALL.xlsx"))
#write_xlsx(out_chi, paste0("Output/", DATE, "_desc_Chisq.xlsx"))

# ----------------------------------------------------------------
# STATISTICAL ANALYSIS
# ----------------------------------------------------------------

# main analysis
m1 <- glm(ahlscore ~ education + gender + agegroup, family="binomial", data=data_comp)
summary(m1)
out_main <- cbind(exp(cbind(OR = coef(m1), confint(m1))), pval = broom::tidy(m1)$p.value) %>% 
  as.data.frame() %>% rownames_to_column(., "var") %>% mutate(model = "m1")

m2 <- glm(ahlscore ~ education + gender + agegroup + auditc_3, family="binomial", data=data_comp)
summary(m2)
out_main <- rbind(out_main, cbind(exp(cbind(OR = coef(m2), confint(m2))), pval = broom::tidy(m2)$p.value) %>% 
                    as.data.frame() %>% rownames_to_column(., "var") %>% mutate(model = "m2"))

m3 <- glm(ahlscore ~ education + gender + agegroup + auditc_3 + hlsscore, family="binomial", data=data_comp)
summary(m3)
out_main <- rbind(out_main, cbind(exp(cbind(OR = coef(m3), confint(m3))), pval = broom::tidy(m3)$p.value) %>% 
                    as.data.frame() %>% rownames_to_column(., "var") %>% mutate(model = "m3"))

# estimate RR based on OR and P0

  # get P0 
  p0_edu <- data_comp %>% group_by(education) %>%
    summarise(p0 = mean(as.numeric(as.character(ahlscore)))) %>% 
    mutate(var = paste0("education", education)) %>%
    dplyr::select(c(p0, var))
  p0_gender <- data_comp %>% group_by(gender) %>%
    summarise(p0 = mean(as.numeric(as.character(ahlscore)))) %>% 
    mutate(var = paste0("gender", gender)) %>%
    dplyr::select(c(p0, var))
  p0_age <- data_comp %>% group_by(agegroup) %>%
    summarise(p0 = mean(as.numeric(as.character(ahlscore)))) %>% 
    mutate(var = paste0("agegroup", agegroup)) %>%
    dplyr::select(c(p0, var))
  p0_auditc <- data_comp %>% group_by(auditc_3) %>%
    summarise(p0 = mean(as.numeric(as.character(ahlscore)))) %>% 
    mutate(var = paste0("auditc_3", auditc_3)) %>%
    dplyr::select(c(p0, var))
  p0_hls <- data_comp %>% group_by(hlsscore) %>%
    summarise(p0 = mean(as.numeric(as.character(ahlscore)))) %>% 
    mutate(var = paste0("hlsscore", hlsscore)) %>%
    dplyr::select(c(p0, var))

  p0 <- rbind(p0_edu, p0_gender, p0_age, p0_auditc, p0_hls)
  
out_main <- merge(out_main, p0, by = "var", all.x = T) %>%
  mutate(RR = OR / ((1 - p0) + (p0 * OR)),
         RR_Low = `2.5 %` / ((1 - p0) + (p0 * `2.5 %`)),
         RR_Up = `97.5 %` / ((1 - p0) + (p0 * `97.5 %`)))
  
# sensitivity analysis (include those with missing AHL)
sm1 <- multinom(ahlscore_mis ~ education + gender + agegroup, data=data)
summary(sm1)
out_sens1 <- cbind(t(exp(coef(sm1))), as.data.frame(exp(confint(sm1)))) %>% 
  as.data.frame() %>% rownames_to_column(., "var") %>% 
  cbind(., pval.inadequate = broom::tidy(sm1)$p.value[1:6], 
        pval.missing = broom::tidy(sm1)$p.value[7:12]) %>% mutate(model = "m1")

sm2 <- multinom(ahlscore_mis ~ education + gender + agegroup + auditc_3, data=data)
summary(sm2)
out_sens2 <- cbind(t(exp(coef(sm2))), as.data.frame(exp(confint(sm2)))) %>% 
  as.data.frame() %>% rownames_to_column(., "var") %>% 
  cbind(., pval.inadequate = broom::tidy(sm2)$p.value[1:8], 
        pval.missing = broom::tidy(sm2)$p.value[9:16]) %>% mutate(model = "m2")

sm3 <- multinom(ahlscore_mis ~ education + gender + agegroup + auditc_3 + hlsscore, data=data)
summary(sm3)
out_sens3 <- cbind(t(exp(coef(sm3))), as.data.frame(exp(confint(sm3)))) %>% 
  as.data.frame() %>% rownames_to_column(., "var") %>% 
  cbind(., pval.inadequate = broom::tidy(sm3)$p.value[1:10], 
        pval.missing = broom::tidy(sm3)$p.value[11:20]) %>% mutate(model = "m3")
out_sens <- rbind(out_sens1, out_sens2, out_sens3)

# estimate RR based on OR and P0

  data <- data %>%
    mutate(ahl_ins = ifelse(ahlscore_mis == "inadequate", 1, 0),
           ahl_mis = ifelse(ahlscore_mis == "missing", 1, 0))
  # get P0 
  p0_edu <- data %>% group_by(education) %>%
    summarise(p0_ins = mean(ahl_ins),
              p0_mis = mean(ahl_mis)) %>% 
    mutate(var = paste0("education", education)) %>%
    dplyr::select(c(p0_ins, p0_mis, var))
  p0_gender <- data %>% group_by(gender) %>%
    summarise(p0_ins = mean(ahl_ins),
              p0_mis = mean(ahl_mis)) %>% 
    mutate(var = paste0("gender", gender)) %>%
    dplyr::select(c(p0_ins, p0_mis, var))
  p0_age <- data %>% group_by(agegroup) %>%
    summarise(p0_ins = mean(ahl_ins),
              p0_mis = mean(ahl_mis)) %>% 
    mutate(var = paste0("agegroup", agegroup)) %>%
    dplyr::select(c(p0_ins, p0_mis, var))
  p0_auditc <- data %>% group_by(auditc_3) %>%
    summarise(p0_ins = mean(ahl_ins),
              p0_mis = mean(ahl_mis)) %>% 
    mutate(var = paste0("auditc_3", auditc_3)) %>%
    dplyr::select(c(p0_ins, p0_mis, var))
  p0_hls <- data %>% group_by(hlsscore) %>%
    summarise(p0_ins = mean(ahl_ins),
              p0_mis = mean(ahl_mis)) %>% 
    mutate(var = paste0("hlsscore", hlsscore)) %>%
    dplyr::select(c(p0_ins, p0_mis, var))
  
  p0 <- rbind(p0_edu, p0_gender, p0_age, p0_auditc, p0_hls)

out_sens <- merge(out_sens, p0, by = "var", all.x = T) %>%
  mutate(RR_ins = inadequate / ((1 - p0_ins) + (inadequate * p0_ins)),
         RR_Low_ins = `2.5 %.inadequate` / ((1 - p0_ins) + (p0_ins * `2.5 %.inadequate`)),
         RR_Up_ins = `97.5 %.inadequate` / ((1 - p0_ins) + (p0_ins * `97.5 %.inadequate`)),
         RR_mis = missing / ((1 - p0_mis) + (missing * p0_mis)),
         RR_Low_mis = `2.5 %.missing` / ((1 - p0_mis) + (p0_mis * `2.5 %.missing`)),
         RR_Up_mis = `97.5 %.missing` / ((1 - p0_mis) + (p0_mis * `97.5 %.missing`)))

#Export
#write_xlsx(out_main, paste0("Output/", DATE, "_LogReg.xlsx"))
#write_xlsx(out_sens, paste0("Output/", DATE, "_MNReg.xlsx"))

# ----------------------------------------------------------------
# EXPLORATIVE VISUALISATIONS
# ----------------------------------------------------------------

col <- c("#AD9AD8", "#A42E9D", "#331453")
theme_barplot <- theme_bw() + 
  theme(axis.text = element_text(size=14, color = "black"),
        legend.text = element_text(size=14, color = "black"),
        strip.text = element_text(size=14),
        title = element_text(size=14),
        axis.title = element_text(size=14, color = "black"),
        legend.position = "none")

# Alcohol-specific diseases

pdat_diseases <- data_comp %>%
  dplyr::select(education, alc_cancer, alc_mental, alc_liver, alc_infection, alc_heart, 
                alc_injury, alc_dementia, alc_fetal, alc_respiratory) %>% 
  pivot_longer(c("alc_cancer", "alc_mental", "alc_liver", "alc_infection", "alc_heart", 
                 "alc_injury", "alc_dementia", "alc_fetal", "alc_respiratory"), 
               names_to = "disease", values_to = "value") %>%
  group_by(education, disease) %>%
  summarise(prop = mean(value)) %>%
  mutate(education = factor(education, levels = c("low", "middle", "high")),
         disease = factor(disease, levels = c("alc_cancer", "alc_liver", "alc_heart", "alc_injury",
                                              "alc_fetal", "alc_mental", "alc_respiratory", "alc_infection",
                                              "alc_dementia"),
                          labels = c("Cancers", "Liver diseases", "Heart diseases", "Injuries",
                                     "Fetal damage", "Mental health conditions", "Respiratory diseases", "Infectious diseases",
                                     "Dementia")))
  
ggplot(pdat_diseases, aes(x = education, y = prop, fill = education)) +
  geom_bar(stat = "identity", position = position_dodge()) + 
  scale_fill_manual(values = col, name = "") +
  scale_y_continuous(labels = scales::percent) + 
  ylab("Agreement that the disease can be caused by alcohol use") +
  xlab("\nEducation") +
  facet_wrap(vars(disease), nrow = 3) +
  theme_barplot 
#ggsave(paste0("Output/", DATE, "_Fig1_AlcDiseases.jpg"), dpi=300, width = 10, height = 8)

# Alcohol safe drinking limits

pdat_maxalc <- data_comp %>%
  dplyr::select(education, maxalc_preg_detail, maxalc_men_detail, maxalc_women_detail) %>% 
  pivot_longer(c("maxalc_preg_detail", "maxalc_men_detail", "maxalc_women_detail"), 
               names_to = "group", values_to = "maxalc") %>%
  filter(!is.na(maxalc)) %>%
  mutate(education = factor(education, levels = c("low", "middle", "high")),
         group = factor(group, levels = c("maxalc_men_detail", "maxalc_women_detail", "maxalc_preg_detail"),
                          labels = c("Men", "Women", "During pregnancy")),
         limit = ifelse(group == "Men", 2, 
                        ifelse(group == "Women", 1,
                               ifelse(group == "During pregnancy", 0, NA))))

ggplot(pdat_maxalc, aes(x = education, y = maxalc)) +
  geom_violin(draw_quantiles = c(0.5)) + 
  geom_jitter(height = 0, width = 0.1) + 
  geom_hline(aes(yintercept = limit), color = "#A42E9D") +
  scale_fill_manual(values = col, name = "") +
  scale_y_continuous(breaks = seq(0, 15, by = 1)) +
  ylab("Level of alcohol use reported to be\nthe threshold of low-risk drinking (in standard drinks)") +
  xlab("\nEducation") +
  facet_wrap(vars(group), ncol = 3) +
  theme_barplot 
#ggsave(paste0("Output/", DATE, "_Fig2_AlcLimits.jpg"), dpi=300, width = 9, height = 6)

pdat_maxalc %>%
  mutate(value = ifelse(maxalc <= limit, 1, ifelse(maxalc > limit, 0, NA))) %>%
  group_by(education, group) %>%
  summarise(correct = mean(value),
            incorrect = 1 - mean(value))
  
# Wrong beliefs 
pdat_beliefs <- data_comp %>%
  dplyr::select(education, health_risk, cancer_risk, wine_health, wine_beer_health) %>% 
  pivot_longer(c("health_risk", "cancer_risk", "wine_health", "wine_beer_health"), 
               names_to = "item", values_to = "agreement") %>%
  mutate(education = factor(education, levels = c("low", "middle", "high")),
         item = factor(item, levels = c("health_risk", "cancer_risk", "wine_health", "wine_beer_health"),
                        labels = c("If I drink more alcohol, there is a greater risk of health harms.",
                                   "If I drink alcohol regularly, I have a greater risk of developing cancer.",
                                   "Drinking one glass of wine a day will benefit my health.",
                                   "It is better for my health to drink a small glass of wine than\na small bottle of beer.")),
         agreement = ifelse(agreement <= 2, 0,
                            ifelse(agreement >= 3, 1, NA))) %>%
  filter(!is.na(agreement)) %>%
  group_by(education, item) %>%
  summarise(agreement = mean(agreement))

ggplot(pdat_beliefs, aes(x = education, y = agreement, fill = education)) +
  geom_bar(stat = "identity", position = position_dodge()) + 
  scale_fill_manual(values = col, name = "") + 
  scale_y_continuous(labels = scales::percent) +  
  ylab("Percentage of respondents who agree with statement") +
  xlab("\nEducation") +
  facet_wrap(vars(item), nrow = 5) +
  theme_barplot 
#ggsave(paste0("Output/", DATE, "_Fig3_Beliefs.jpg"), dpi=300, width = 7, height = 10)

# Understanding health information
pdat_und <- data_comp %>%
  dplyr::select(education, understand_health_info) %>%
  mutate(education = factor(education, levels = c("low", "middle", "high")),
         level = factor(understand_health_info, levels = c(4,3,2,1),
                        labels = c("Very easy", "Easy", "Difficult", "Very difficult"))) %>%
  group_by(education, level) %>%
  summarise(count = n()) %>%
  group_by(education) %>%
  mutate(prop = count / sum(count))

ggplot(pdat_und, aes(x = education, y = prop, fill = education)) +
  geom_bar(stat = "identity", position = position_dodge()) + 
  scale_fill_manual(values = col, name = "") + 
  scale_y_continuous(labels = scales::percent) +  
  ylab("Percentage of respondents who indicated each response") +
  xlab("\nEducation") +
  facet_wrap(vars(level), nrow = 1) +
  theme_barplot 
#ggsave(paste0("Output/", DATE, "_Fig4_UndHealthInfo.jpg"), dpi=300, width = 12, height = 6)

